@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-__version_info__ = (2, 1, 6)
+__version_info__ = (2, 1, 7)
 __version__ = '.'.join(map(str, __version_info__))
 
 
@@ -19,7 +19,7 @@ __all__ = ('quantize', 'CURRENCIES', 'INVOICE_DUE', 'INVOICE_CANCELED',
 
 import re
 from xml.dom.minidom import Document
-from datetime import datetime, date, time
+from datetime import datetime, date, time, timedelta
 from decimal import (Decimal, getcontext, Context, ROUND_HALF_UP,
                      DivisionByZero, InvalidOperation)
 try:
@@ -658,7 +658,7 @@ class Invoice(ExtensibleXMLiElement):
         @param value:datetime
         '''
         value = date_to_datetime(value)
-        if value > datetime.now():
+        if value > datetime.now() + timedelta(hours=14, minutes=1): #More or less 14 hours from now in case the submitted date was local
             raise ValueError("Date cannot be in the future.")
 
         if self.__due_date and value.date() > self.__due_date:
